@@ -9,7 +9,7 @@ use Params::ValidationCompiler 0.13 qw( validation_for );
 use Specio::Declare;
 use Storable qw( dclone );
 
-our $VERSION = '1.31';
+our $VERSION = '1.37';
 
 my @FormatLengths;
 
@@ -289,7 +289,7 @@ DateTime::Locale::FromData - Class for locale objects instantiated from pre-defi
 
 =head1 VERSION
 
-version 1.31
+version 1.37
 
 =head1 SYNOPSIS
 
@@ -338,8 +338,8 @@ component, plus optional territory and variant components. Something like
 
 =head2 $locale->variant
 
-The relevant component from the locale's complete name, like "English"
-or "United States".
+The relevant component from the locale's complete name, like "English" or
+"United States".
 
 =head2 $locale->native_name
 
@@ -445,8 +445,8 @@ method.
 
 =head2 $locale->format_for($name)
 
-These are accessed by passing a name to C<< $locale->format_for(...)  >>,
-where the name is a CLDR-style format specifier.
+These are accessed by passing a name to C<< $locale->format_for(...)  >>, where
+the name is a CLDR-style format specifier.
 
 The return value is a string suitable for passing to C<< $dt->format_cldr >>,
 so you can do something like this:
@@ -462,8 +462,8 @@ Chinese characters for "day" (日) and month (月), so you get something like
 
 =head2 $locale->available_formats
 
-This should return a list of all the format names that could be passed
-to C<< $locale->format_for >>.
+This should return a list of all the format names that could be passed to C<<
+$locale->format_for >>.
 
 See the documentation for individual locales for details and examples of these
 formats. The format names that are available vary by locale.
@@ -480,8 +480,8 @@ formats. The format names that are available vary by locale.
 
 These methods return strings appropriate for the C<< DateTime->strftime >>
 method. However, you are strongly encouraged to use the other format methods,
-which use the CLDR format data. They are primarily included for the benefit
-for L<DateTime::Format::Strptime>.
+which use the CLDR format data. They are primarily included for the benefit for
+L<DateTime::Format::Strptime>.
 
 =head2 $locale->version
 
@@ -493,13 +493,13 @@ Returns a boolean indicating whether or not the locale prefers 24-hour time.
 
 =head2 $locale->first_day_of_week
 
-Returns a number from 1 to 7 indicating the I<local> first day of the
-week, with Monday being 1 and Sunday being 7.
+Returns a number from 1 to 7 indicating the I<local> first day of the week,
+with Monday being 1 and Sunday being 7.
 
 =head2 $locale->locale_data
 
-Returns a clone of the original data used to create this locale as a hash.
-This is here to facilitate creating custom locales via
+Returns a clone of the original data used to create this locale as a hash. This
+is here to facilitate creating custom locales via
 C<DateTime::Locale->register_data_locale>.
 
 =head1 SUPPORT
@@ -509,8 +509,6 @@ Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issu
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
@@ -521,7 +519,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2003 - 2020 by Dave Rolsky.
+This software is copyright (c) 2003 - 2022 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
