@@ -13,49 +13,50 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "LLL y G",
-    GyMMMEd => "E, d MMM y G",
+    GyMMMEd => "E d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E, d/M",
+    MEd => "E d/M",
     MMM => "MMM",
-    MMMEd => "E, d MMM",
-    MMMMEd => "E, d MMMM",
+    MMMEd => "E d MMM",
+    MMMMEd => "E d MMMM",
     "MMMMW-count-one" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} W \N{U+03c4}\N{U+03bf}\N{U+03c5} MMMM",
     "MMMMW-count-other" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} W \N{U+03c4}\N{U+03bf}\N{U+03c5} MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "d/M",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M/y",
-    yMEd => "E, d/M/y",
+    yMEd => "E d/M/y",
     yMMM => "MMM y",
-    yMMMEd => "E, d MMM y",
+    yMMMEd => "E d MMM y",
     yMMMM => "LLLL y",
     yMMMd => "d MMM y",
     yMd => "d/M/y",
-    yQQQ => "y QQQ",
-    yQQQQ => "y QQQQ",
+    yQQQ => "QQQ y",
+    yQQQQ => "QQQQ y",
     "yw-count-one" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} w \N{U+03c4}\N{U+03bf}\N{U+03c5} Y",
     "yw-count-other" => "\N{U+03b5}\N{U+03b2}\N{U+03b4}\N{U+03bf}\N{U+03bc}\N{U+03ac}\N{U+03b4}\N{U+03b1} w \N{U+03c4}\N{U+03bf}\N{U+03c5} Y",
   },
   code => "el-GR",
-  date_format_full => "EEEE, d MMMM y",
+  date_format_full => "EEEE d MMMM y",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "d/M/yy",
@@ -264,10 +265,10 @@
   ],
   script => undef,
   territory => "Greece",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 35,
+  version => 42,
 }
