@@ -13,14 +13,15 @@
     EHm => "E H.mm",
     EHms => "E H.mm.ss",
     Ed => "E d.",
-    Ehm => "E h.mm a",
-    Ehms => "E h.mm.ss a",
+    Ehm => "E h.mm\N{U+202f}a",
+    Ehms => "E h.mm.ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "LLL y G",
     GyMMMEd => "E d. MMM y G",
     GyMMMMEd => "E d. MMMM y G",
     GyMMMMd => "d. MMMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "M.d.y G",
     H => "H",
     Hm => "H.mm",
     Hms => "H.mm.ss",
@@ -37,11 +38,11 @@
     MMMd => "d. MMM",
     Md => "d.M.",
     d => "d",
-    h => "h a",
-    hm => "h.mm a",
-    hms => "h.mm.ss a",
-    hmsv => "h.mm.ss a v",
-    hmv => "h.mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h.mm\N{U+202f}a",
+    hms => "h.mm.ss\N{U+202f}a",
+    hmsv => "h.mm.ss\N{U+202f}a v",
+    hmv => "h.mm\N{U+202f}a v",
     ms => "m.ss",
     y => "y",
     yM => "L.y",
@@ -65,9 +66,9 @@
   date_format_long => "d. MMMM y",
   date_format_medium => "d.M.y",
   date_format_short => "d.M.y",
-  datetime_format_full => "{1} 'klo' {0}",
-  datetime_format_long => "{1} 'klo' {0}",
-  datetime_format_medium => "{1} 'klo' {0}",
+  datetime_format_full => "{1} {0}",
+  datetime_format_long => "{1} {0}",
+  datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "ma",
@@ -275,5 +276,5 @@
   time_format_medium => "H.mm.ss",
   time_format_short => "H.mm",
   variant => undef,
-  version => 38,
+  version => 42,
 }
