@@ -13,12 +13,13 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "dd/MM/y GGGGG",
     H => "HH 'h'",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -34,11 +35,11 @@
     MMMd => "d MMM",
     Md => "dd/MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM/y",
@@ -58,9 +59,9 @@
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "dd/MM/y",
-  datetime_format_full => "{1} '\N{U+00e0}' {0}",
-  datetime_format_long => "{1} '\N{U+00e0}' {0}",
-  datetime_format_medium => "{1} '\N{U+00e0}' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
+  datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "lun.",
@@ -268,5 +269,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 42,
 }
