@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "AM",
-    "PM",
+    "SF",
+    "YM",
   ],
   available_formats => {
     Bh => "h B",
@@ -19,6 +19,7 @@
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -29,14 +30,15 @@
     MMM => "LLL",
     MMMEd => "E, MMM d",
     MMMMEd => "E, MMMM d",
-    "MMMMW-count-other" => "'week' W 'of' MMMM",
+    "MMMMW-count-one" => "'satin' W 'cikin' MMMM",
+    "MMMMW-count-other" => "'satin' W 'cikin' MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "M/d",
     d => "d",
     h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
@@ -50,17 +52,18 @@
     yMd => "y-MM-dd",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-one" => "'sati' w 'cikin' Y",
+    "yw-count-other" => "'sati' w 'cikin' Y",
   },
   code => "ha-NG",
-  date_format_full => "EEEE, d MMMM, y",
+  date_format_full => "EEEE d MMMM, y",
   date_format_long => "d MMMM, y",
   date_format_medium => "d MMM, y",
   date_format_short => "d/M/yy",
   datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  datetime_format_long => "{1}, {0}",
+  datetime_format_medium => "{1}, {0}",
+  datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
     "Lit",
     "Tal",
@@ -116,11 +119,11 @@
     "Lahadi",
   ],
   era_abbreviated => [
-    "KHAI",
+    "K.H",
     "BHAI",
   ],
   era_narrow => [
-    "KHAI",
+    "K.H",
     "BHAI",
   ],
   era_wide => [
@@ -128,9 +131,9 @@
     "Bayan haihuwar annab",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "ranar %A, %d ga %B cikin %r %Z",
   glibc_date_format => "%d/%m/%y",
-  glibc_datetime_format => "ranar %A, %d ga %B cikin %r %Z",
+  glibc_datetime_format => "ranar %A, %d ga %B cikin %r",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%r",
   language => "Hausa",
@@ -220,9 +223,9 @@
   ],
   name => "Hausa Nigeria",
   native_language => "Hausa",
-  native_name => "Hausa Najeriya",
+  native_name => "Hausa Nijeriya",
   native_script => undef,
-  native_territory => "Najeriya",
+  native_territory => "Nijeriya",
   native_variant => undef,
   quarter_format_abbreviated => [
     "K1",
@@ -267,5 +270,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 33,
+  version => 42,
 }
