@@ -19,6 +19,7 @@
     GyMMM => "G y MMM",
     GyMMMEd => "G y MMM d, E",
     GyMMMd => "G y MMM d",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -261,10 +262,10 @@
   ],
   script => undef,
   territory => undef,
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "HH:mm:ss zzzz",
+  time_format_long => "HH:mm:ss z",
+  time_format_medium => "HH:mm:ss",
+  time_format_short => "HH:mm",
   variant => undef,
-  version => 38,
+  version => 42,
 }
