@@ -7,18 +7,19 @@
     Bh => "B h",
     Bhm => "B h:mm",
     Bhms => "B h:mm:ss",
-    E => "ccc\N{U+1014}\N{U+1031}\N{U+1037}",
+    E => "ccc",
     EBhm => "E B h:mm",
     EBhms => "E B h:mm:ss",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
-    Ed => "d \N{U+101b}\N{U+1000}\N{U+103a} E\N{U+1014}\N{U+1031}\N{U+1037}",
+    Ed => "d \N{U+101b}\N{U+1000}\N{U+103a} E",
     Ehm => "E B h:mm",
     Ehms => "E B h:mm:ss",
     Gy => "G y",
     GyMMM => "G y MMM",
     GyMMMEd => "G y\N{U+104a} MMM d\N{U+104a} E",
     GyMMMd => "G y\N{U+104a} MMM d",
+    GyMd => "G y/M/d",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -28,7 +29,7 @@
     MEd => "d/M\N{U+104a} E",
     MMM => "LLL",
     MMMEd => "MMM d\N{U+104a} E",
-    MMMMEd => "MMMM d \N{U+101b}\N{U+1000}\N{U+103a} E\N{U+1014}\N{U+1031}\N{U+1037}",
+    MMMMEd => "MMMM d \N{U+101b}\N{U+1000}\N{U+103a} E",
     "MMMMW-count-other" => "MMMM \N{U+101c} W \N{U+1015}\N{U+1010}\N{U+103a}\N{U+1019}\N{U+103c}\N{U+1031}\N{U+102c}\N{U+1000}\N{U+103a}",
     MMMMd => "MMMM d",
     MMMd => "d MMM",
@@ -47,16 +48,16 @@
     yMMMEd => "y\N{U+104a} MMM d\N{U+104a} E",
     yMMMM => "y MMMM",
     yMMMd => "y\N{U+104a} MMM d",
-    yMd => "dd-MM-y",
+    yMd => "d/M/y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
     "yw-count-other" => "Y \N{U+1001}\N{U+102f} w \N{U+1015}\N{U+1010}\N{U+103a}\N{U+1019}\N{U+103c}\N{U+1031}\N{U+102c}\N{U+1000}\N{U+103a}",
   },
   code => "my",
   date_format_full => "y\N{U+104a} MMMM d\N{U+104a} EEEE",
-  date_format_long => "y\N{U+104a} d MMMM",
+  date_format_long => "y\N{U+104a} MMMM d",
   date_format_medium => "y\N{U+104a} MMM d",
-  date_format_short => "dd-MM-yy",
+  date_format_short => "d/M/yy",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
@@ -264,8 +265,8 @@
   territory => undef,
   time_format_full => "zzzz HH:mm:ss",
   time_format_long => "z HH:mm:ss",
-  time_format_medium => "B HH:mm:ss",
-  time_format_short => "B H:mm",
+  time_format_medium => "H:mm:ss",
+  time_format_short => "H:mm",
   variant => undef,
-  version => 38,
+  version => 42,
 }
