@@ -13,19 +13,20 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d.",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E d. MMM y G",
     GyMMMd => "d. MMM y G",
+    GyMd => "dd.MM.y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L.",
-    MEd => "E d.M",
+    MEd => "E d.M.",
     MMM => "LLL",
     MMMEd => "E d. MMM",
     "MMMMW-count-one" => "'veke' W 'i' MMMM",
@@ -35,11 +36,11 @@
     MMdd => "d.M.",
     Md => "d.M.",
     d => "d.",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "M.y",
@@ -127,8 +128,8 @@
     "e.Kr.",
   ],
   era_wide => [
-    "f.Kr.",
-    "e.Kr.",
+    "f\N{U+00f8}r Kristus",
+    "etter Kristus",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %d. %b %H:%M:%S %z %Y",
@@ -222,8 +223,8 @@
     "desember",
   ],
   name => "Norwegian Nynorsk Norway",
-  native_language => "nynorsk",
-  native_name => "nynorsk Noreg",
+  native_language => "norsk nynorsk",
+  native_name => "norsk nynorsk Noreg",
   native_script => undef,
   native_territory => "Noreg",
   native_variant => undef,
@@ -270,5 +271,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 42,
 }
