@@ -35,8 +35,8 @@
     Md => "d/M",
     d => "d",
     h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
     hmsv => "h:mm:ss a v",
     hmv => "h:mm a v",
     ms => "m:ss",
@@ -262,10 +262,10 @@
   ],
   script => undef,
   territory => "South Sudan",
-  time_format_full => "zzzz h:mm:ss a",
-  time_format_long => "z h:mm:ss a",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "zzzz h:mm:ss\N{U+202f}a",
+  time_format_long => "z h:mm:ss\N{U+202f}a",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 40,
+  version => 42,
 }
