@@ -1,7 +1,7 @@
 {
   am_pm_abbreviated => [
-    "sn.",
-    "gn.",
+    "GH",
+    "GD",
   ],
   available_formats => {
     Bh => "h B",
@@ -15,10 +15,11 @@
     Ed => "d, E",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
-    Gy => "G y",
-    GyMMM => "G y MMM",
-    GyMMMEd => "G y MMM d, E",
-    GyMMMd => "G y MMM d",
+    Gy => "y G",
+    GyMMM => "MMM y G",
+    GyMMMEd => "E, MMM d, y G",
+    GyMMMd => "MMM d, y G",
+    GyMd => "M/d/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -29,8 +30,8 @@
     MMM => "LLL",
     MMMEd => "E, MMM d",
     MMMMEd => "E, MMMM d",
-    "MMMMW-count-one" => "'usbuuc' W 'ee' MMMM",
-    "MMMMW-count-other" => "'usbuuc' W 'ee' MMMM",
+    "MMMMW-count-one" => "'toddobaadka' W 'ee' MMMM",
+    "MMMMW-count-other" => "'toddobaadka' W 'ee' MMMM",
     MMMMd => "MMMM d",
     MMMd => "MMM d",
     Md => "M/d",
@@ -38,7 +39,7 @@
     h => "h a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
+    hmsv => "h:mm:ss\N{U+202f}a v",
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
@@ -47,15 +48,16 @@
     yMMM => "MMM y",
     yMMMEd => "E, MMM d, y",
     yMMMM => "MMMM y",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
+    yMMMd => "MMM d, y",
+    yMd => "M/d/y",
     yQQQ => "QQQ y",
     yQQQQ => "QQQQ y",
-    "yw-count-other" => "'week' w 'of' Y",
+    "yw-count-one" => "'toddobaadka' w 'ee' Y",
+    "yw-count-other" => "'toddobaadka' w 'ee' Y",
   },
   code => "so-DJ",
-  date_format_full => "EEEE, MMMM dd, y",
-  date_format_long => "dd MMMM y",
+  date_format_full => "EEEE, MMMM d, y",
+  date_format_long => "MMMM d, y",
   date_format_medium => "dd-MMM-y",
   date_format_short => "dd/MM/yy",
   datetime_format_full => "{1} {0}",
@@ -64,11 +66,11 @@
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
     "Isn",
-    "Tal",
-    "Arb",
-    "Kha",
-    "Jim",
-    "Sab",
+    "Tldo",
+    "Arbc",
+    "Khms",
+    "Jmc",
+    "Sbti",
     "Axd",
   ],
   day_format_narrow => [
@@ -91,11 +93,11 @@
   ],
   day_stand_alone_abbreviated => [
     "Isn",
-    "Tal",
-    "Arb",
-    "Kha",
-    "Jim",
-    "Sab",
+    "Tldo",
+    "Arbc",
+    "Khms",
+    "Jmc",
+    "Sbti",
     "Axd",
   ],
   day_stand_alone_narrow => [
@@ -117,51 +119,51 @@
     "Axad",
   ],
   era_abbreviated => [
-    "CK",
-    "CD",
+    "BC",
+    "AD",
   ],
   era_narrow => [
-    "CK",
-    "CD",
+    "B",
+    "A",
   ],
   era_wide => [
-    "CK",
-    "CD",
+    "Ciise Hortii",
+    "Ciise Dabadii",
   ],
   first_day_of_week => 6,
   glibc_date_1_format => "%a %b %e %r %Z %Y",
   glibc_date_format => "%d.%m.%Y",
   glibc_datetime_format => "%a %d %b %Y %r %Z",
-  glibc_time_12_format => "%X %p",
-  glibc_time_format => "%l:%M:%S",
+  glibc_time_12_format => "%l:%M:%S %p",
+  glibc_time_format => "%l:%M:%S %p",
   language => "Somali",
   month_format_abbreviated => [
-    "Kob",
-    "Lab",
-    "Sad",
-    "Afr",
-    "Sha",
-    "Lix",
-    "Tod",
-    "Sid",
-    "Sag",
-    "Tob",
-    "KIT",
-    "LIT",
+    "Jan",
+    "Feb",
+    "Mar",
+    "Abr",
+    "May",
+    "Jun",
+    "Lul",
+    "Ogs",
+    "Seb",
+    "Okt",
+    "Nof",
+    "Dis",
   ],
   month_format_narrow => [
-    "K",
-    "L",
-    "S",
+    "J",
+    "F",
+    "M",
     "A",
-    "S",
+    "M",
+    "J",
     "L",
-    "T",
+    "O",
     "S",
-    "S",
-    "T",
-    "K",
-    "L",
+    "O",
+    "N",
+    "D",
   ],
   month_format_wide => [
     "Bisha Koobaad",
@@ -178,46 +180,46 @@
     "Bisha Laba iyo Tobnaad",
   ],
   month_stand_alone_abbreviated => [
-    "Kob",
-    "Lab",
-    "Sad",
-    "Afr",
-    "Sha",
-    "Lix",
-    "Tod",
-    "Sid",
-    "Sag",
-    "Tob",
-    "KIT",
-    "LIT",
+    "Jan",
+    "Feb",
+    "Mar",
+    "Abr",
+    "May",
+    "Jun",
+    "Lul",
+    "Ogs",
+    "Seb",
+    "Okt",
+    "Nof",
+    "Dis",
   ],
   month_stand_alone_narrow => [
-    1,
-    2,
-    3,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
+    "J",
+    "F",
+    "M",
+    "A",
+    "M",
+    "J",
+    "L",
+    "O",
+    "S",
+    "O",
+    "N",
+    "D",
   ],
   month_stand_alone_wide => [
-    "Bisha Koobaad",
-    "Bisha Labaad",
-    "Bisha Saddexaad",
-    "Bisha Afraad",
-    "Bisha Shanaad",
-    "Bisha Lixaad",
-    "Bisha Todobaad",
-    "Bisha Sideedaad",
-    "Bisha Sagaalaad",
-    "Bisha Tobnaad",
-    "Bisha Kow iyo Tobnaad",
-    "Bisha Laba iyo Tobnaad",
+    "Jannaayo",
+    "Febraayo",
+    "Maarso",
+    "Abriil",
+    "May",
+    "Juun",
+    "Luuliyo",
+    "Ogosto",
+    "Sebteembar",
+    "Oktoobar",
+    "Noofeembar",
+    "Diseembar",
   ],
   name => "Somali Djibouti",
   native_language => "Soomaali",
@@ -263,10 +265,10 @@
   ],
   script => undef,
   territory => "Djibouti",
-  time_format_full => "h:mm:ss a zzzz",
-  time_format_long => "h:mm:ss a z",
-  time_format_medium => "h:mm:ss a",
-  time_format_short => "h:mm a",
+  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
+  time_format_long => "h:mm:ss\N{U+202f}a z",
+  time_format_medium => "h:mm:ss\N{U+202f}a",
+  time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 33,
+  version => 42,
 }
