@@ -12,49 +12,50 @@
     EBhms => "E h:mm:ss B",
     EHm => "E, HH:mm",
     EHms => "E, HH:mm:ss",
-    Ed => "E, d",
+    Ed => "d, E",
     Ehm => "E h:mm a",
     Ehms => "E h:mm:ss a",
-    Gy => "G y '\N{U+0435}\N{U+043b}'",
-    GyMMM => "G y '\N{U+0435}\N{U+043b}', MMM",
-    GyMMMEd => "E, G d MMM y '\N{U+0435}\N{U+043b}'",
-    GyMMMd => "G d MMM y '\N{U+0435}\N{U+043b}'",
+    Gy => "G y\N{U+202f}'\N{U+0435}\N{U+043b}'",
+    GyMMM => "G y\N{U+202f}'\N{U+0435}\N{U+043b}', MMM",
+    GyMMMEd => "G y\N{U+202f}'\N{U+0435}\N{U+043b}', d MMM, E",
+    GyMMMd => "G y\N{U+202f}'\N{U+0435}\N{U+043b}', d MMM",
+    GyMd => "GGGGG y-MM-dd",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E, dd.MM",
+    MEd => "dd.MM, E",
     MMM => "LLL",
-    MMMEd => "E, d MMM",
+    MMMEd => "d MMM, E",
     "MMMMW-count-other" => "MMMM '\N{U+0430}\N{U+0435}\N{U+043d}\N{U+044b}\N{U+04a3}' W '\N{U+0430}\N{U+0442}\N{U+043d}\N{U+0430}\N{U+0441}\N{U+044b}'",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     Md => "dd.MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM.y",
-    yMEd => "E, dd.MM.y",
-    yMMM => "MMM, y '\N{U+0435}\N{U+043b}'",
-    yMMMEd => "E, d MMM, y '\N{U+0435}\N{U+043b}'",
-    yMMMM => "MMMM, y '\N{U+0435}\N{U+043b}'",
-    yMMMd => "d MMM, y '\N{U+0435}\N{U+043b}'",
+    yMEd => "dd.MM.y, E",
+    yMMM => "y\N{U+202f}'\N{U+0435}\N{U+043b}', MMM",
+    yMMMEd => "y\N{U+202f}'\N{U+0435}\N{U+043b}', d MMM, E",
+    yMMMM => "y\N{U+202f}'\N{U+0435}\N{U+043b}', MMMM",
+    yMMMd => "y\N{U+202f}'\N{U+0435}\N{U+043b}', d MMM",
     yMd => "dd.MM.y",
-    yQQQ => "QQQ, y '\N{U+0435}\N{U+043b}'",
-    yQQQQ => "QQQQ, y '\N{U+0435}\N{U+043b}'",
+    yQQQ => "y\N{U+202f}'\N{U+0435}\N{U+043b}', QQQ",
+    yQQQQ => "y\N{U+202f}'\N{U+0435}\N{U+043b}', QQQQ",
     "yw-count-other" => "Y '\N{U+0435}\N{U+043b}\N{U+043d}\N{U+044b}\N{U+04a3}' w '\N{U+0430}\N{U+0442}\N{U+043d}\N{U+0430}\N{U+0441}\N{U+044b}'",
   },
   code => "tt",
-  date_format_full => "d MMMM, y '\N{U+0435}\N{U+043b}', EEEE",
-  date_format_long => "d MMMM, y '\N{U+0435}\N{U+043b}'",
-  date_format_medium => "d MMM, y '\N{U+0435}\N{U+043b}'",
+  date_format_full => "d MMMM, y\N{U+202f}'\N{U+0435}\N{U+043b}', EEEE",
+  date_format_long => "d MMMM, y\N{U+202f}'\N{U+0435}\N{U+043b}'",
+  date_format_medium => "d MMM, y\N{U+202f}'\N{U+0435}\N{U+043b}'",
   date_format_short => "dd.MM.y",
   datetime_format_full => "{1}, {0}",
   datetime_format_long => "{1}, {0}",
@@ -116,15 +117,15 @@
   ],
   era_abbreviated => [
     "\N{U+0431}.\N{U+044d}.\N{U+043a}.",
-    "\N{U+0431}.\N{U+044d}.",
+    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+0430}\N{U+0434}\N{U+0438}",
   ],
   era_narrow => [
     "\N{U+0431}.\N{U+044d}.\N{U+043a}.",
-    "\N{U+0431}.\N{U+044d}.",
+    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+0430}\N{U+0434}\N{U+0438}",
   ],
   era_wide => [
     "\N{U+0431}\N{U+0435}\N{U+0437}\N{U+043d}\N{U+0435}\N{U+04a3} \N{U+044d}\N{U+0440}\N{U+0430}\N{U+0433}\N{U+0430} \N{U+043a}\N{U+0430}\N{U+0434}\N{U+04d9}\N{U+0440}",
-    "\N{U+0431}\N{U+0435}\N{U+0437}\N{U+043d}\N{U+0435}\N{U+04a3} \N{U+044d}\N{U+0440}\N{U+0430}",
+    "\N{U+043c}\N{U+0438}\N{U+043b}\N{U+0430}\N{U+0434}\N{U+0438}",
   ],
   first_day_of_week => 1,
   glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
@@ -266,5 +267,5 @@
   time_format_medium => "H:mm:ss",
   time_format_short => "H:mm",
   variant => undef,
-  version => 35,
+  version => 42,
 }
