@@ -13,12 +13,12 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E, d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
-    GyMMM => "LLL y '\N{U+0440}'. G",
-    GyMMMEd => "E, d MMM y '\N{U+0440}'. G",
-    GyMMMd => "d MMM y '\N{U+0440}'. G",
+    GyMMM => "LLL y\N{U+202f}'\N{U+0440}'. G",
+    GyMMMEd => "E, d MMM y\N{U+202f}'\N{U+0440}'. G",
+    GyMMMd => "d MMM y\N{U+202f}'\N{U+0440}'. G",
     GyMd => "dd-MM-y GGGGG",
     H => "HH",
     Hm => "HH:mm",
@@ -38,34 +38,34 @@
     MMMd => "d MMM",
     Md => "dd.MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM.y",
     yMEd => "E, dd.MM.y",
-    yMMM => "LLL y '\N{U+0440}'.",
-    yMMMEd => "E, d MMM y '\N{U+0440}'.",
-    yMMMM => "LLLL y '\N{U+0440}'.",
-    yMMMd => "d MMM y '\N{U+0440}'.",
+    yMMM => "LLL y\N{U+202f}'\N{U+0440}'.",
+    yMMMEd => "E, d MMM y\N{U+202f}'\N{U+0440}'.",
+    yMMMM => "LLLL y\N{U+202f}'\N{U+0440}'.",
+    yMMMd => "d MMM y\N{U+202f}'\N{U+0440}'.",
     yMd => "dd.MM.y",
     yQQQ => "QQQ y",
-    yQQQQ => "QQQQ y '\N{U+0440}'.",
+    yQQQQ => "QQQQ y\N{U+202f}'\N{U+0440}'.",
     "yw-count-few" => "w-'\N{U+0439}' '\N{U+0442}\N{U+0438}\N{U+0436}'. Y '\N{U+0440}'.",
     "yw-count-many" => "w-'\N{U+0439}' '\N{U+0442}\N{U+0438}\N{U+0436}'. Y '\N{U+0440}'.",
     "yw-count-one" => "w-'\N{U+0439}' '\N{U+0442}\N{U+0438}\N{U+0436}'. Y '\N{U+0440}'.",
     "yw-count-other" => "w-'\N{U+0439}' '\N{U+0442}\N{U+0438}\N{U+0436}'. Y '\N{U+0440}'.",
   },
   code => "uk-UA",
-  date_format_full => "EEEE, d MMMM y '\N{U+0440}'.",
-  date_format_long => "d MMMM y '\N{U+0440}'.",
-  date_format_medium => "d MMM y '\N{U+0440}'.",
+  date_format_full => "EEEE, d MMMM y\N{U+202f}'\N{U+0440}'.",
+  date_format_long => "d MMMM y\N{U+202f}'\N{U+0440}'.",
+  date_format_medium => "d MMM y\N{U+202f}'\N{U+0440}'.",
   date_format_short => "dd.MM.yy",
-  datetime_format_full => "{1} '\N{U+043e}' {0}",
-  datetime_format_long => "{1} '\N{U+043e}' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -274,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 40,
+  version => 42,
 }
